from app.extensions import AuditMixin, db

author_identifier = db.Table('author_identifier',
    db.Column('book_id', db.Integer, db.ForeignKey('book.id')),
    db.Column('author_id', db.Integer, db.ForeignKey('author.id'))
)

class Book(db.Model, AuditMixin):
    """The model for a book."""
    __tablename__ = 'book'

    id = db.Column(db.Integer, primary_key=True)
    isbn_10 = db.Column(db.Text, unique=True, nullable=False)
    isbn_13 = db.Column(db.Text, unique=True, nullable=False)
    authors = db.relationship('Author', secondary=author_identifier)
    categories = db.Column(db.Text)
    description = db.Column(db.Text)
    publisher = db.Column(db.Text, nullable=False)
    published_date = db.Column(db.Integer, nullable=False)
    title = db.Column(db.Text, nullable=False)
    thumbnail = db.Column(db.Text, nullable=False)
    small_thumbnail = db.Column(db.Text, nullable=False)
    subtitle = db.Column(db.Text)

    def serialize(self):
        j = {}
        j['id'] = self.id
        j['isbn_10'] = self.isbn_10
        j['isbn_13'] = self.isbn_13
        j['authors'] = [author.serialize() for author in self.authors]
        j['categories'] = self.categories
        j['description'] = self.description
        j['publisher'] = self.publisher
        j['published_date'] = self.published_date
        j['title'] = self.title
        j['thumbnail'] = self.thumbnail
        j['small_thumbnail'] = self.small_thumbnail
        j['subtitle'] = self.subtitle

        return j
