"""
utils.py

Contains various utility functions used throughout the app.

Created by Stephen Andrews, September 27th, 2018.
"""

from app.extensions import db
from app.models import User, VerificationList
from sqlalchemy import and_

from exponent_server_sdk import DeviceNotRegisteredError
from exponent_server_sdk import PushClient
from exponent_server_sdk import PushMessage
from exponent_server_sdk import PushResponseError
from exponent_server_sdk import PushServerError
from requests.exceptions import ConnectionError
from requests.exceptions import HTTPError

import requests

def send_email(to, subject, msg):
    """
    Send an email.

    :param to: The email recipient.
    :param subject: The email subject.
    :param msg: The email content.
    :return: The response object.
    """
    endpoint = 'https://api.mailgun.net/v3/sandbox54a4744944ae424184ed2510d1c65987.mailgun.org/messages'
    auth = ('api', '09934567750cd90e55bcad070407910d-b0aac6d0-4d5222f5')
    data = {
        'from': 'BookStand <admin@bookstand.io>',
        'to': to,
        'subject': subject,
        'text': msg
    }

    return requests.post(endpoint, auth=auth, data=data)

def send_push_message(user_id, message, extra=None):
    print('Attempting to send message to user ID: {} message: {}'.format(user_id, message))

    # user = User.query.filter_by(id=user_id).first()
    # if not user:
    #     return
    
    # if not user.expo_token:
    #     print('User {} disabled push notifications')
    #     return
    
    try:
        # print('Sending push notification: user_id={} message={} extra={}'.format(user_id, message, extra))
        response = PushClient().publish(
            PushMessage(to=user_id,
                        body=message,
                        data=extra))
    except PushServerError as exc:
        # # Encountered some likely formatting/validation error.
        # rollbar.report_exc_info(
        #     extra_data={
        #         'token': token,
        #         'message': message,
        #         'extra': extra,
        #         'errors': exc.errors,
        #         'response_data': exc.response_data,
        #     })
        raise
    except (ConnectionError, HTTPError) as exc:
        # Encountered some Connection or HTTP error - retry a few times in
        # case it is transient.
        # rollbar.report_exc_info(
        #     extra_data={'token': token, 'message': message, 'extra': extra})
        # raise self.retry(exc=exc)
        print(exc)
    try:
        # We got a response back, but we don't know whether it's an error yet.
        # This call raises errors so we can handle them with normal exception
        # flows.
        response.validate_response()
    except DeviceNotRegisteredError:
        # # Mark the push token as inactive
        # from notifications.models import PushToken
        # PushToken.objects.filter(token=token).update(active=False)
        print(exc)
    except PushResponseError as exc:
        print(exc)
        # Encountered some other per-notification error.
        # rollbar.report_exc_info(
        #     extra_data={
        #         'token': token,
        #         'message': message,
        #         'extra': extra,
        #         'push_response': exc.push_response._asdict(),
        #     })
        # raise self.retry(exc=exc)

# verify the session_id
def verify_session(session_id):
    entry = VerificationList.query.filter(and_(
        VerificationList.session_id==session_id,
        VerificationList.valid==True)).first()
    if not entry:
        return False
    return True