"""
library.py

API endpoints for interacting with owned books

Created by Theodore Bieber, October 4th, 2018.
"""

from flask import Blueprint, jsonify, render_template, request

from app.extensions import db
from app.models import User, OwnedList

from sqlalchemy import and_, or_

from app.utils import verify_session

library = Blueprint('library', __name__)

@library.before_request
def authorize():
    """Require authorization for all views."""
    if not request.headers.get('authorization'):
        return 'unauthorized', 401
    temp = request.headers['authorization'].split(' ')
    if not len(temp) == 2:
        return 'invalid authorization header'
    if not verify_session(temp[1]):
        return 'unauthorized', 401

@library.route('/<string:user_id>', methods=['GET'])
@library.route('/<string:user_id>&p=<int:page_number>', methods=['GET'])
@library.route('/<string:user_id>&p=<int:page_number>&c=<int:count>', methods=['GET'])
def get(user_id, page_number=1, count=5):
    if user_id:
        library = OwnedList.query.filter(and_(
            OwnedList.visible==True,
            OwnedList.user_id==user_id
        )).paginate(page_number, count).items
        if not library:
            return 'user_id {} doesn\'t exist in table owned'.format(user_id), 400

        return jsonify([l.serialize() for l in library])
    # Idk what this is tbh - ted
    return jsonify([own.serialize() for own in OwnedList.query.all()])

@library.route('/add', methods=['POST'])
def add():
    content = request.json

    library = OwnedList(**content)
    db.session.add(library)
    db.session.commit()

    return jsonify(library.serialize())


# hide a listing from your library. similar in functionality to removing it, but its still technically there
@library.route('/remove/<string:id>', methods=['DELETE'])
def remove(id):
    entry = OwnedList.query.filter(OwnedList.id==id).first()

    if not entry:
        return 'library id {} invalid'.format(id), 404

    entry.visible = False
    db.session.commit()

    return 'library entry deleted', 200
 