"""
test_listing.py

Tests API endpoint for listings.

Created by Stephen Andrews, September 19th, 2018.
"""

import json
import os

import pytest

from app.models import Book, Listing, University, User, VerificationList
from app.views.book import get_book_by_isbn


ART_OF_SQL = Book(isbn_10='0596008945', isbn_13='9780596008949', description='desc', publisher='O\'Reilly Media', published_date=2007, title='The Art of SQL', thumbnail='', small_thumbnail='')
TEST_USER = User(username='stephen', password=b'C4F8A99346F22B355978F380EF05AFDB44C5DDA26E9DDF8AC31196DFE79C2E3A', university_id=1, email='sandrews@wpi.edu', session_id='1')
WPI = University(university_name='WPI', city='Worcester', state='MA', country='USA', timezone='EST')
VERIFICATION = VerificationList(session_id='1', valid=True)

@pytest.mark.parametrize('init_database', [[WPI, TEST_USER, ART_OF_SQL, VERIFICATION]], indirect=True)
@pytest.mark.parametrize('seller, book, condition, description', [
    (TEST_USER, ART_OF_SQL, 'Excellent', 'Some description...'),
])
def test_post_listing(test_client, init_database, seller, book, condition, description):
    """Test listing endpoint."""

    payload = {}
    payload['seller_id'] = seller.id
    payload['book_id'] = book.id
    payload['condition'] = condition
    payload['description'] = description

    response = test_client.post('listing/post',
                                data=json.dumps(payload),
                                content_type='application/json',
                                headers={'Authorization': 'Bearer 1'})
    assert response.status_code == 200

@pytest.mark.parametrize('init_database', [[WPI, TEST_USER, ART_OF_SQL]], indirect=True)
@pytest.mark.parametrize('seller, book, condition, description, price', [
    (TEST_USER, ART_OF_SQL, 'Excellent', 'Some description...', 4.20),
])
def test_post_sale(test_client, init_database, seller, book, condition, description, price):
    """Test listing endpoint for sale creation."""

    payload = {}
    payload['seller_id'] = seller.id
    payload['book_id'] = book.id
    payload['condition'] = condition
    payload['description'] = description

    response = test_client.post('listing/post',
                                data=json.dumps(payload),
                                content_type='application/json',
                                headers={'Authorization': 'Bearer 1'})
    assert response.status_code == 200
