"""
discovery.py

Created by Stephen Andrews, March 2017
"""

import requests

from util.logger import Logger

class Discovery(Logger):
    """Utility class for the discovery scripts."""

    # How many times to retry the request before moving on
    ATTEMPT_THRESHOLD = 5

    def __init__(self, **kwargs):
        super().__init__(**kwargs)
        self.logger.info('Starting up %s', kwargs['logfile_name'])

    def send_request(self, url, attempt=0, **kwargs):
        """
        Sends a request to the specified url with the option of supplying
        headers and other parameters. Returns json if the request was successful.

        This function will attempt to send the request until the attempt threshold
        has been met.
        """
        response = requests.get(url, **kwargs)
        if response.status_code == requests.codes.not_found:
            self.logger.critical('Not found 404: {}'.format(url))
            return None

        if response.status_code == requests.codes.unauthorized:
            self.logger.critical('Unauthorized 401: {}'.format(url))
            return None

        if response.status_code != requests.codes.ok:
            self.logger.warning('Unexpected response from server: {}'.format(response))
            self.logger.info('[Attempt #{}] Retrying request on page: {}'.format(attempt, url))

            if attempt > self.ATTEMPT_THRESHOLD:
                self.logger.warning('Attempt limit reached!')
                return None
            else:
                time.sleep(5)  # Wait a bit before sending the request again
                return self.send_request(url, attempt + 1, **kwargs)

        return response.json()
