import React from 'react';
import {
  StyleSheet,
} from 'react-native';

import {
  createStackNavigator,
  createBottomTabNavigator,
} from 'react-navigation';

import Icon from 'react-native-vector-icons/Feather';

import StorageManager from './src/StorageManager';

import Login from './src/views/login/Login';
import Register from './src/views/register/Register';

// Browse screens
import BrowseView from "./src/views/browse/BrowseView";
import ListingView from './src/views/browse/ListingView';
import DetailedView from './src/views/browse/DetailedView';

import CameraView from './src/views/create_listing/CameraView';
import CreateListing from './src/views/create_listing/CreateListing';
import ConditionSelection from './src/views/create_listing/ConditionSelection';
import Barcode from './src/views/barcodes/Barcode';
import SelectBook from './src/views/select_book/SelectBook';
import LoadingScreen from './src/views/LoadingScreen';
import Profile from './src/views/profile/Profile';
import Forgot from './src/views/forgot/Forgot';
import AddBookToShelf from './src/views/bookshelf/AddBookToShelf';
import Messaging from './src/views/messaging/Messaging';
import Conversation from './src/views/messaging/Conversation';
import TransactionHistory from './src/views/transactions/TransactionHistory';
import ActiveListings from './src/views/profile/ActiveListings';


const MessagingStack = createStackNavigator({
  Messaging:{
    screen: Messaging
  },
  Conversation:{
    screen: Conversation
  },
},
{
  initialRouteName: 'Messaging',
  navigationOptions: {
    header: null,
    headerStyle: {
      backgroundColor: '#FDFDFE',
    },
    headerTintColor: '#fff',
    headerTintStyle: {
      fontWeight: 'bold',
    },
  },
});

const BrowseViewStack = createStackNavigator({
  BrowseView: {screen: BrowseView},
  Listings: {screen: ListingView},
  DetailedView:  {screen: DetailedView}
},
{
  initialRouteName: 'BrowseView',
  navigationOptions: {
    header: null,
    headerStyle: {
      backgroundColor: '#FDFDFE',
    },
    headerTintColor: '#fff',
    headerTintStyle: {
      fontWeight: 'bold',
    },
  },
});

BrowseViewStack.navigationOptions = ({ navigation }) => {
  let tabBarVisible = true
  if (navigation.state.index == 2) {
    tabBarVisible = false;
  }  

  return {
    tabBarVisible,
  };
};

const CreateListingStack = createStackNavigator({
  CreateListing: {screen: CreateListing},
  SelectBook: {screen: SelectBook},
  Barcode: {screen: Barcode},
  ConditionSelection: {screen: ConditionSelection},
  CameraView: {screen: CameraView},
},
{
  initialRouteName: 'CreateListing',
  navigationOptions: {
    header: null,
    headerStyle: {
      backgroundColor: '#FDFDFE',
    },
    headerTintColor: '#fff',
    headerTintStyle: {
      fontWeight: 'bold',
    },
  },
});

// Hide tab bar on listing screen
CreateListingStack.navigationOptions = ({ navigation }) => {
  let tabBarVisible = true
  if (navigation.state.index == 1) {
    tabBarVisible = false;
  }  

  return {
    tabBarVisible,
  };
};

const BookShelfStack = createStackNavigator({
  Profile: {screen: Profile},
  AddBookToShelf: {screen: AddBookToShelf},
  Barcode: {screen: Barcode},
  CameraView: {screen: CameraView},
  TransactionHistory: {screen: TransactionHistory},
  ActiveListings: {screen: ActiveListings},
  DetailedView: {screen: DetailedView}
},
{
  initialRouteName: 'Profile',
  navigationOptions: {
    header: null,
    headerStyle: {
      backgroundColor: '#FDFDFE',
    },
    headerTintColor: '#fff',
    headerTintStyle: {
      fontWeight: 'bold',
    },
  },
})

const TabNav = createBottomTabNavigator({
  // Dashboard: {
  //   screen: Dashboard,
  //   navigationOptions: {
  //     tabBarLabel: 'Dashboard',
  //     tabBarIcon: ({ tintColor, focused }) => (
  //       <Icon name="home" size={25} color={tintColor} />
  //     ),
  //   }
  // },
  Listings: {
    screen: BrowseViewStack,
    navigationOptions: {
      tabBarLabel: 'Browse',
      tabBarIcon: ({ tintColor, focused }) => (
        <Icon name="book" size={25} color={tintColor} />
      ),
    }
  },
  CreateListing: {
    screen: CreateListingStack,
    navigationOptions: {
      tabBarLabel: 'Sell',
      tabBarIcon: ({ tintColor, focused }) => (
        <Icon name="tag" size={25} color={tintColor} />
      ),
    }
  },
  Messaging: {
    screen: MessagingStack,
    navigationOptions: {
      tabBarLabel: 'Messages',
      tabBarIcon: ({ tintColor, focused }) => (
        <Icon name="message-circle" size={25} color={tintColor} />
      ),
    }
  },
  Profile: {
    screen: BookShelfStack,
    navigationOptions: {
      tabBarIcon: ({ tintColor, focused }) => (
        <Icon name="user" size={25} color={tintColor} />
      ),
    }
  },
},
{
  initialRouteName: 'Listings',
  
  barStyle: { backgroundColor: '#694fad' },
  backBehavior: 'initialRoute',
  tabBarOptions: {
    showLabel: false,
    // style: {backgroundColor: 'red'},
    // activeBackgroundColor: '#f0edf6',
    activeTintColor: '#0078FC',
    // inactiveBackgroundColor: 'blue',
    // inactiveTintColor: 'gray',
  },
});

const Init = createStackNavigator({
  LoadingScreen: {
    screen: LoadingScreen
  },
  Forgot: {
    screen: Forgot
  },
  Login: {
    screen: Login
  },
  Register: {
    screen: Register
  },
  Dashboard: {
    screen: TabNav
  }
},
{
  initialRouteName: 'LoadingScreen',
  navigationOptions: {
    header: null,
    headerStyle: {
      backgroundColor: '#FDFDFE',
    },
    headerTintColor: '#fff',
    headerTintStyle: {
      fontWeight: 'bold',
    },
  },
});


/**
 * Returns the stack view that should be shown on startup.
 */
getStartupStack = () => {
  StorageManager.getItem("remember_me", (flag) => {
    console.log("Remember me: " + flag);
    if (flag === "true") {
      // TODO: API call to verify session.
      return TabNav;
    } else {
      return Init;
    }
  });

  return Init;
}

export default getStartupStack();