/**
 * @author Theodore Bieber
 * @author Stephen Andrews
 * @since 9/26/2018
 */
import {AsyncStorage} from "react-native"

let StorageManager = {

  /**
   * Gets a single key from the user's local storage.
   * @param key The name of the key to get.
   * @param callback The callback function containing the value.
   * @param onFail An optional callback that will get called if the key doesn't exist.
   */
  getItem : async (key, callback, onFail) => {
    try {
      const value = await AsyncStorage.getItem(key);

      if (value !== null) {
        callback(value);
      } else {
        if (onFail !== undefined) {
          onFail();
        }
      }
    } catch (error) {
      console.log("[Storage Manager] Error loading key: " + key);
      console.log(error);
    }
  },

  /**
   * 
   */
  getItems : async (keys, callback) => {
    try {
      AsyncStorage.multiGet(keys, (err, stores) => {
        stores.map((result, index, store) => {
          // console.log(store);
        });

        callback();
      });
    } catch (error) {
      console.log("[Storage Manager] Error loading keys: " + keys);
    }
  },

  /**
   * Stores a key value pair on the user's local storage.
   * @param key The name of the value you want to store.
   * @param value The value you want to store.
   */
  putItem : async (key, value) => {
    try {
      return await AsyncStorage.setItem(String(key), String(value));
    } catch (error) {
      console.log("[Storage Manager] Error storing key: " + key);
      console.log(error);
    }
  },
}

var session_id = "";

export default StorageManager;
