import React, { Component } from "react";
import { 
  Image,
  View, 
  Text, 
  StyleSheet 
} from "react-native";

/**
 * Displays a book cover, title, authors, and tags.
 * @author Stephen Andrews
 */
export default class BookEntry extends Component {
  
  /**
   * Renders the authors.
   * @return A text component containing the authors.
   */
  renderAuthors() {
    let authors = [];
    console.log(this.props.book.authors);
    for (var author of this.props.book.authors) {
      if (author.first_name || author.last_name) {
        authors.push(author.first_name + " " + author.last_name);
      } else {
        authors.push(author);
      }
    }

    return <Text style={styles.subtitle}>{authors.join(", ")}</Text>;
  }

  /**
   * Renders the categories (if any) for a book.
   * @return A view containing the book's categories in tag components.
   */
  renderTags() {
    if (!this.props.book.categories) {
      return <View></View>;
    }

    components = [];
    tags = this.props.book.categories.split(" & ");
    for (var tag of tags) {
      components.push(
        <View key={tag} style={styles.tag}>
          <Text style={styles.tagText}>{tag}</Text>
        </View>
      );
    }

    return <View style={styles.tagContainer}>{components}</View>;
  }

  render() {
    return (
      <View style={styles.container}>
        <View style={styles.thumbnailContainer}>
          <Image
            source={{ uri: this.props.book.thumbnail }}
            style={styles.thumbnailStyle}
          />
        </View>

        {/* Text content and tags */}
        <View style={styles.content}>
          <Text numberOfLines={2} style={styles.title}>
            {this.props.book.title}
          </Text>

          {this.renderAuthors()}

          {/* Wrapping in a view to anchor tags to bottom of touchable component */}
          <View style={{ flex: 1, justifyContent: "flex-end" }}>
            {this.renderTags()}
          </View>
        </View>
      </View>
    );
  }
}

const styles = StyleSheet.create({
  container: {
    flex: 1,
    flexDirection: "row",
  },
  content: {
    flex: 1,
    paddingLeft: 10,
    paddingRight: 10,
  },
  tagContainer: {
    flexDirection: "row"
  },
  tag: {
    alignSelf: "flex-start",
    backgroundColor: "#F6F6F7",
    borderRadius: 5,
    marginRight: 10,
    padding: 10
  },
  tagText: {
    color: "#ACAFB2",
    fontWeight: "500"
  },
  thumbnailContainer: {
    shadowColor: 'black',
    shadowOffset: {width: 0, height: 0},
    shadowRadius: 5,
    shadowOpacity: 0.40,
    elevation: 5
  },
  thumbnailStyle: { // odds are we will want to preserve the aspect ratio but keeping a generalized size
    margin: 5,
    borderRadius: 4,
    width: 75,
    height: 125,
  },
  title: {
    color: '#464A53',
    fontSize: 18,
    fontWeight: '900',
    marginBottom: 5
  },
  subtitle: {
    color: '#ACAFB2',
    fontSize: 16,
    fontWeight: '700',
    marginBottom: 15
  },
});
