import React, { Component } from 'react';

import {
  Platform,
  View,
  StyleSheet,
  Text,
  TouchableOpacity
} from 'react-native';

import Icon from 'react-native-vector-icons/Feather';

/**
 * Smaller header with navigation option to go back to the previous screen.
 * 
 * Usage: `<NavigateableHeader title="Some Title" {...this.props} />`
 * 
 * It is imperative you pass properties with access to the navigation 
 * for the back button to work.
 * 
 * @author Stephen Andrews
 * @since 11.24.18
 */
export default class NavigableHeader extends Component {
  render() {
    return (
      <View style={styles.container}>
        <View 
          flexDirection="row"
          alignItems="center">

          {/* Left container */}
          <View style={styles.leftContainer}>
            <TouchableOpacity
              onPress={() => this.props.navigation.goBack()}>
              <Icon name="arrow-left" color="#000" size={30} />
            </TouchableOpacity>
          </View>
          
          {/* Middle expanding container */}
          <View>
            <Text style={styles.heading}>{this.props.title}</Text>
          </View>
          
          {/* Right container */}
          <View style={styles.rightContainer}></View>
        </View>
      </View>
    );
  }
}

const styles = StyleSheet.create({
  container: {
    height: 100,
    paddingBottom: 15,
    paddingHorizontal: 15,
    justifyContent: 'flex-end',
    backgroundColor: '#FFF'
  },
  leftContainer: {
    flex: 1
  },
  rightContainer: {
    flex: 1
  },
  heading: {
    color: '#000',
    fontSize: 16,
    fontFamily: Platform.OS === 'ios' ? 'Helvetica' : 'Roboto',
    fontWeight: '500'
  }
});
