import React, { Component } from 'react';

import {
  View,
} from 'react-native';

/**
 * Render a row based view with left, middle, and right components evenly spaced.
 * The middle component will always be rendered at the center of the screen.
 * 
 * Usage:
 * ```
 * <SplitView left={} center={} right={} style={}/>
 * ```
 * @author Stephen Andrews
 * @since 11.30.18
 */
export default class Header extends Component {
  render() {
    return (
      <View 
        flex={1}
        flexDirection="row" 
        justifyContent="space-between" 
        alignItems="center"
        style={{...this.props.style}}>
        
        {/* Render left hand component */}
        <View flex={1}>
          { this.props.left }
        </View>

        {/* Render center component */}
        <View>
          { this.props.center}
        </View>

        {/* Render right component */}
        <View flex={1}>
          { this.props.right }
        </View>

      </View>
    );
  }
}
