import React, {
    Component
  } from 'react';
  import {
    Platform,
    View,
    Text,
    StyleSheet,
    FlatList,
    ActivityIndicator
  } from 'react-native';
  
  import API from '../../API';
  import StorageManager from '../../StorageManager';
  import Header from '../../components/Header';
  import DisplayItem from './DisplayItem';
  
  export default class DisplayCase extends Component {
    constructor() {
      super();
      this.state = {
        isLoading: true,
        owned: [],
        pagesLoaded: 0,
      };
    }
  
    componentDidMount() {
      let cb = (response) => {
        books = [];
        return response.json().then((data) => {
            this.setState({
              isLoading: false,
              owned: data,
              pagesLoaded: 1,
            });
          }).catch((error) => {
            this.setState({
              isLoading: false,
              owned: [],
              pagesLoaded: 0,
            });
          });
      }
      StorageManager.getItem('user_id', (response)=>{
        API.getOwned(response, cb);
        return;
      }, (response) => {
        this.setState({
          isLoading:false,
          owned:[],
          pagesLoaded:0,
        });
      });
    }
    
    // pass down to item so that when you remove it, it can call it
    onRemovedItem = (reslist) => {
      // Load the first page with the size of the current list
      let cb = (response) => {
        response.json().then((data) => {
          this.setState({
            isLoading: false,
            owned: data,
            pagesLoaded: this.state.pagesLoaded,
          });
        }, () => {
          this.setState({
            isLoading: false,
            owned: [],
            pagesLoaded: 0,
          });
        });
      }
      // API Call, ask for pages loaded+1
      StorageManager.getItem('user_id', (response)=>{
        API.getOwned(response, cb, 1, this.state.owned.length);
        return;
      }, (response) => {
        this.setState({
          isLoading:false,
          owned:this.state.owned,
          pagesLoaded:this.state.pagesLoaded,
        });
      });
    }

    loadNextPage = () => {
      let cb = (response) => {
        response.json().then((data) => {
          this.setState({
            isLoading: false,
            owned: this.state.owned.concat(data),
            pagesLoaded: this.state.pagesLoaded+1,
          });
        }, () => {
        });
      }
      // API Call, ask for pages loaded+1
      StorageManager.getItem('user_id', (response)=>{
        API.getOwned(response, cb, this.state.pagesLoaded+1);
        return;
      }, (response) => {
        this.setState({
          isLoading:false,
          owned:this.state.owned,
          pagesLoaded:this.state.pagesLoaded,
        });
      });
    }

    refresh = () => { // Bring this out to another function? used in componentdidmount
      let cb = (response) => {
        books = [];
        return response.json().then((data) => {
            this.setState({
              isLoading: false,
              owned: data,
              pagesLoaded: 1,
            });
          }).catch((error) => {
            this.setState({
              isLoading: false,
              owned: [],
              pagesLoaded: 1,
            });
          });
      }
      StorageManager.getItem('user_id', (response)=>{
        API.getOwned(response, cb);
        return;
      }, (response) => {
        this.setState({
          isLoading:false,
          owned:[],
          pagesLoaded:0,
        });
      });
    }

    render() {
      {/* Show loading indicator until API returns response */}
      if (this.state.isLoading) {
        return (
          <View style={{flex: 1, justifyContent: 'center'}}>
            <ActivityIndicator />
          </View>
        );
      }
  
      return (
        <View style={styles.container}>
          <FlatList
            data={this.state.owned}
            keyExtractor={(item) => item.id+""}
            renderItem={({item}) => <DisplayItem {...this.props} item={item} onRemovedItem={this.onRemovedItem}/>}
            // Added for pagination (below)
            onEndReachedThreshold={0.25}
            onEndReached={this.loadNextPage}
            onRefresh={this.refresh}
            refreshing={false}
          />
        </View>
      );
    }
  }
  
  const styles = StyleSheet.create({
    container: {
      flex: 1,
    },
    heading: {
      color: '#FFFFFF',
      fontSize: 42,
      fontFamily: Platform.OS === 'ios' ? 'Helvetica' : 'Roboto',
      fontWeight: '500',
      marginBottom: 15,
      marginLeft: 15
    },
  
  });
  