import React, {
  Component
} from 'react';

import {
  StatusBar,
  StyleSheet,
  View,
  Platform
} from 'react-native';

import Header from '../../components/Header';
import BrowseListView from './BrowseListView';

import API from '../../API';
import StorageManager from '../../StorageManager';
import {Notifications} from 'expo';

/**
 * Defines the aggregate listings screen.
 * @author Stephen Andrews, John Bieber, Ted Bieber
 */
export default class BrowseView extends Component {

  componentDidMount = () => {
    StorageManager.getItem('user_id', (result) => {
      API.registerForPushNotifications(result);
    }, ()=> {
      console.log('User does not currently have a user_id in storage.');
    });
    
    this._notificationSubscription = Notifications.addListener(this._handleNotification);

  }

  _handleNotification = (notification) => {
    let cb = (response) => {
      this.props.navigation.navigate('Conversation', {
        'user_id1': response, 
        'user_id2': notification.data.data
      });
    }
    
    console.log(Platform.OS);
    console.log(notification.origin)

    // Only do action if it was pressed by user
    // these differ on ios and android
    if (Platform.OS ==='ios') {
      if (notification.origin === 'received' || notification.origin === 'selected') {
        StorageManager.getItem('user_id', cb);
      }
    } else if (Platform.OS === 'android') {
      if (notification.origin === 'selected') {
        StorageManager.getItem('user_id', cb);
      }
    }
  }

  getReturnScreen = () => {
    if (this.props.navigation.state &&
        this.props.navigation.state.params &&
        this.props.navigation.state.params.screen) {

      return this.props.navigation.state.params.screen
    } else {
      return <BrowseListView {...this.props} />
    }
  }

  render() {
    return (
      <View style={styles.container}>
        <StatusBar barStyle="dark-content" /> 
        <Header title="Browse" />

        {/* Enable this when designing individual listings, quicker debugging so you dont have to navigate to the screen */}
        {/* <SaleListView bookId={2} {...this.props} /> */}
        <BrowseListView {...this.props} />
      </View>
    );
  }
}

const styles = StyleSheet.create({
  container: {
    flex: 1,
    backgroundColor: '#FDFDFE'
  },

});
