import React, {
    Component,
    PureComponent
  } from 'react';
  import {
    View,
    Text,
    StyleSheet,
  } from 'react-native';
  
  import StorageManager from '../../StorageManager';
  import ImageCard from '../../components/ImageCard';

/**
 * Renders individual listings in the SaleListView component.
 * @author Stephen Andrews
 * @since 10.4.18
 */
export default class SaleItem extends PureComponent {

  constructor() {
    super();

    this.state = {
      accent: "",
      user_id: ""
    }
  }

  componentWillMount() {
    // TODO: Improve how accent is set
    this.setState({
      accent: this.props.listing.condition.toUpperCase() === "good".toUpperCase() ? styles.yellowAccent : styles.greenAccent,
      user_id: this.state.user_id
    });

    // get our user id
    StorageManager.getItem('user_id', (response) => {
      this.setState({
        accent: this.state.accent,
        user_id: response
      });
    });
  }

  /**
   * The action to perform when pressing a card.
   */
  onPressedTouchable = () => {
    this.props.navigation.navigate('DetailedView', {
      'listing': this.props.listing,
      'user_id': this.state.user_id
    });
  }

  render() {
    let defaultImage = 'https://s3.amazonaws.com/bookstand/photo/puppy/picture' + (1 + Math.floor(Math.random() * Math.floor(96)) + '.jpeg');
    let image = this.props.listing.photos && this.props.listing.photos.length > 0 ? this.props.listing.photos[0] : defaultImage;
    let price = this.props.listing.price > 0 ? "$" + this.props.listing.price : "Free";

    return (
      <View style={styles.container}>

        {/* Render an image card for each listing */}
        <ImageCard uri={image} onPress={this.onPressedTouchable}>
          <View style={{flexDirection: "row", justifyContent: "space-between", marginBottom: 5}}>
            <Text style={[styles.p, this.state.accent]}>{this.props.listing.condition.toUpperCase()}</Text>
            <Text style={styles.p}>{this.props.listing.slang_created}</Text>
          </View>

          <View style={{flexDirection: "row", justifyContent: "space-between", marginBottom: 5}}>
            <Text style={styles.h1}>{price}</Text>
            <Text style={[styles.h1, {marginBottom: 5}]}>{this.props.listing.seller.username}</Text>
          </View>
    
          {/* Give description its own row since it can push adjacent elements off screen */}
          <Text 
            numberOfLines={3}
            style={styles.p}>{this.props.listing.description}</Text>
        </ImageCard>
      </View>
    );
  }
}

const styles = StyleSheet.create({
  container: {
    backgroundColor: '#FDFDFE',
    flex: 1,
    paddingHorizontal: 20,
    paddingVertical: 10,
  },
  h1: {
    color: '#464A53',
    fontSize: 18,
    fontWeight: '700',
  },
  p: {
    color: '#A99691',
    fontSize: 14,
    fontWeight: '500',
  },
  greenAccent: {
    color: '#7ADF00',
  },
  yellowAccent: {
    color: '#F2BB69',
  },
});
