import React, {
    Component
  } from 'react';
import {
    StyleSheet,
    Text,
    TouchableOpacity,
    View,
} from 'react-native';
  
import NavigableHeader from '../../components/NavigableHeader';

// TODO: Would be nice to have this in the backend database
let NEW_DESCRIPTION = `A new, unread, unused book in perfect condition
with no missing or damaged pages.`

let EXCELLENT_DESCRIPTION = `A book that looks new but has been read. No 
missing or damaged pages, no creases or tears, and no underlining/highlighting 
of text or writing in the margins. Very minimal wear and tear.`

let GOOD_DESCRIPTION = `Very minimal damage to the cover including scuff marks, but 
no holes or tears. The majority of pages are undamaged with minimal creasing or tearing, 
minimal pencil underlining of text, no highlighting of text, no writing in margins. 
No missing pages.`

let ACCEPTABLE_DESCRIPTION = `A book with obvious wear. May have some damage to the 
cover but integrity still intact. Possible writing in margins, possible underlining 
and highlighting of text, but no missing pages or anything that would compromise the 
legibility or understanding of the text.`

/**
 * Screen to select book condition for a posting.
 * @author Stephen Andrews
 */
export default class CreateListing extends Component {
  
  /**
   * Replace line breaks of multiline strings so they wrap
   * correctly when rendered.
   * @param str The string to remove line breaks from.
   */
  formatStr = (str) => {
    return str.replace(/(?:\r\n|\r|\n)/g, ' ');
  }

  /**
   * Return to listing screen with selected condition.
   * @param option The name of the selected condition.
   */
  selectCondition = (option) => {
    this.props.navigation.navigate(
      this.props.navigation.state.params.returnScreen, 
      {condition: option}
    );
  }

  /**
   * Render an {@link TouchableOpacity} component containing a
   * title and description representing a book condition.
   * @param title The title of the condition.
   * @param description A description of the condition.
   */
  renderOption = (title, description) => {
      return (
        <TouchableOpacity 
          onPress={() => this.selectCondition(title)}
          style={styles.optionButton}>
          <Text style={styles.header}>{title}</Text>
          <Text style={styles.subHeader}>{description}</Text>
        </TouchableOpacity>
      );
  }

  render() {  
    return (
      <View style={styles.container}>
        <NavigableHeader title="Condition" {...this.props} />

        { this.renderOption('Brand New', this.formatStr(NEW_DESCRIPTION))}
        { this.renderOption('Excellent', this.formatStr(EXCELLENT_DESCRIPTION)) }
        { this.renderOption('Good', this.formatStr(GOOD_DESCRIPTION)) }
        { this.renderOption('Acceptable', this.formatStr(ACCEPTABLE_DESCRIPTION)) }
      </View>
    );
  }
}

const styles = StyleSheet.create({
  container: {
    backgroundColor: '#F6F6FB',
    flex: 1
  },
  optionButton: {
      backgroundColor: '#FFF',
      paddingHorizontal: 20,
      paddingTop: 20
  },
  header: {
      fontSize: 16,
      fontWeight: '500',
      marginBottom: 10
  },
  subHeader: {
      color: '#979797',
      fontWeight: '500'
  }
});
