import React, {
  Component
} from 'react';
import {
  Alert,
  View,
  Text,
  TextInput,
  TouchableOpacity,
  StyleSheet,
} from 'react-native';

import {NavigationActions, StackActions} from 'react-navigation';

import StorageManager from '../../StorageManager';
import API from '../../API';

export default class LoginForm extends Component {
  constructor() {
    super();
    this.state = {
      username: "",
      password: "",
    };

  }

  // Reset stack navigator so users cannot "swipe back" to login screen
  _navigateTo = (routeName) => {
    const actionToDispatch = StackActions.reset({
      index: 0,
      actions: [NavigationActions.navigate({ routeName: routeName })]
    });
    this.props.navigation.dispatch(actionToDispatch);
  }

  /**
   * Makes a call to the API to attempt a login.
   */
  attemptLogin = () => {
    let callback = (response) => {
      if (response.status == 200) {
        // Alert.alert("Success!");
        response.json().then((data) => {
          StorageManager.putItem("remember_me", true);
          StorageManager.putItem("username", data.username);
          StorageManager.putItem("session_id", data.session_id);
          StorageManager.putItem("user_id", data.user_id);
          StorageManager.putItem("email", data.email);
          StorageManager.putItem("university_id", data.university_id);
          StorageManager.putItem("profile_picture", data.profile_picture);
          this._navigateTo('Dashboard');
        });
        
      } else {
        Alert.alert("Incorrect username or password!");
      }
    }

    API.loginUser(this.state.username, this.state.password, callback);
  }

  /**
   * Updates the login form with the current username and password.
   * @param username The current username typed.
   * @param password The current password typed.
   */
  updateForm = (username, password) => {
    this.state.username = username;
    this.state.password = password;
  }

  render() { // TODO: may want to change the switch a little? idk
      return (
        <View style={styles.container}>
          <Text
            onPress={() => this.props.navigation.navigate('Forgot')}
            style={[styles.label, {marginBottom: 15}]}>{"Forgot your password?"}</Text>

          <TextInput
            autoCapitalize="none"
            autoCorrect={false}
            // keyboardType="email-address"
            placeholder="Username"
            returnKeyType="next"
            onChangeText={(text) => this.updateForm(text, this.state.password)}
            onSubmitEditing={() => this.passwordInput.focus()}
            style={styles.input}
            />

          <TextInput
            placeholder="Password"
            returnKeyType="go"
            onChangeText={(text) => this.updateForm(this.state.username, text)}
            secureTextEntry
            style={styles.input}
            ref={(input) => this.passwordInput = input}
            />

          <TouchableOpacity
            onPress={this.attemptLogin}
            style={styles.buttonContainer}>
            <Text style={styles.buttonText}>Login</Text>
          </TouchableOpacity>

          <Text
            onPress={() => this.props.navigation.navigate('Register')}
            style={styles.label}>{"Don't have an account? Sign Up"}</Text>
        </View>
      );
    }
}

const styles = StyleSheet.create({
  container: {
    paddingHorizontal: 20
  },
  buttonContainer: {
    backgroundColor: '#4392EF',
    borderRadius: 4,
    height: 50,
    paddingVertical: 12
  },
  buttonText: {
    color: '#FFF',
    fontSize: 18,
    fontWeight: '500',
    textAlign: 'center'
  },
  input: {
    backgroundColor: '#F2F5F7',
    borderRadius: 4,
    fontSize: 14,
    fontWeight: '500',
    height: 50,
    marginBottom: 15,
    paddingHorizontal: 10,
    opacity: 1.0,
  },
  label: {
    color: '#464A53',
    fontWeight: '500',
    marginTop: 15,
    textAlign: 'center'
  }
});
