/**
 * The file for a conversation
 * This is the deepest level of the messaging system
 * Holds and formats the individual messages that make up a conversation or messaging thread
 * @author Ted Bieber, Stephen Andrews
 * @since 10.25.2018
 */

import React, {
    Component
  } from 'react';
  
  import {
    KeyboardAvoidingView,
    StyleSheet,
    Text,
    TextInput,
    TouchableOpacity,
    View
  } from 'react-native';
  
  import API from '../../API';
  import StorageManager from '../../StorageManager';
  import ConversationListView from './ConversationListView';
  import NavigableHeader from '../../components/NavigableHeader';

  export default class Conversation extends Component {

    constructor() {
      super();

      this.state = {
        message: "",
        to_id:"",
        to_username:"",
        from_id:"",
        conversationId:"",
        isLoading:true,
      };
    }

    // TODO: make the loading for this screen happen faster (the info doesn't appear immediately)
    componentWillMount() {
      let tempId1 = this.props.navigation.state.params.user_id1;
      let tempId2 = this.props.navigation.state.params.user_id2;

      let cb2 = (response) => {
        response.json().then(data => {
          this.setState({
            message:this.state.message,
            to_id:this.state.to_id,
            to_username:(data.to_user.user_id == this.state.from_id ? data.from_user.username : data.to_user.username),
            from_id:this.state.from_id,
            conversationId:data.id,
            isLoading:false,
          });
        });
      }

      let cb = (response) => {
        this.setState({
          message:this.state.message,
          to_id: (response == tempId1 ? tempId2:tempId1),
          to_username:this.state.to_username,
          from_id:response,
          conversationId:this.state.conversationId,
          isLoading:this.state.isLoading,
        });
        API.getThreadByUserIDs(tempId1, tempId2, cb2);
      }
      StorageManager.getItem('user_id', cb);
    }

    /**
     * Sends a message from the current user to the other user
     * participating in the conversation.
     */
    sendMessage = () => {
      if(this.state.message.length == 0) return;
      
      // TODO: needs to update the screen to show our message somehow
      API.sendMessage(this.state.from_id, this.state.to_id, this.state.message, (response) => { 
        this.setState({
          message: "",
          to_id:this.state.to_id,
          to_username:this.state.to_username,
          from_id:this.state.from_id,
          conversationId:this.state.conversationId,
        });
      });
    }

    render() {
      if(this.state.isLoading) { // hardly any difference here, but in this one there's no empty view
        return (
          <KeyboardAvoidingView behavior="padding" style={styles.container}>
            <NavigableHeader title={this.state.to_username} {...this.props} />
            <View style={{ flex: 1 }}></View>
           
            {/* Messaging form */}
            <View style={styles.horizontalView}>
              <TextInput
                placeholder="Message"
                returnKeyType="send"
                onChangeText={(text) => {
                    this.setState({
                      message: text,
                      to_id:this.state.to_id,
                      to_username:this.state.to_username,
                      from_id:this.state.from_id,
                      conversationId:this.state.conversationId,
                    });
                  }
                }
                style={styles.input}
                onSubmitEditing={this.sendMessage}
                value={this.state.message}
                />
              <TouchableOpacity
                onPress={this.sendMessage}
                style={styles.buttonContainer}>
                <Text style={styles.buttonText}>Send</Text>
              </TouchableOpacity>          
            </View>
          </KeyboardAvoidingView>
        )
      } 
      return (
        <KeyboardAvoidingView behavior="padding" style={styles.container}>
          <NavigableHeader title={this.state.to_username} {...this.props} />
          
          <ConversationListView style={{ flex: 1 }} {...this.props} to_username={this.state.to_username} conversationId={this.state.conversationId} needsRender={true}/>
          
          {/* Messaging form */}
          <View style={styles.horizontalView}>
            <TextInput
              placeholder="Message"
              returnKeyType="send"
              onChangeText={(text) => {
                  this.setState({
                    message: text,
                    to_id:this.state.to_id,
                    to_username:this.state.to_username,
                    from_id:this.state.from_id,
                    conversationId:this.state.conversationId,
                  });
                }
              }
              style={styles.input}
              onSubmitEditing={this.sendMessage}
              value={this.state.message}
              />
            <TouchableOpacity
              onPress={this.sendMessage}
              style={styles.buttonContainer}>
              <Text style={styles.buttonText}>Send</Text>
            </TouchableOpacity>          
          </View>
        </KeyboardAvoidingView>
      );
    }
  }
  
  const styles = StyleSheet.create({
    container: {
      flex: 1,
      backgroundColor: '#FDFDFE'
    },
    buttonContainer: {
      backgroundColor: '#4392EF',
      borderRadius: 4,
      height: 50,
      padding: 12,
    },
    buttonText: {
      color: '#FFF',
      fontSize: 18,
      fontWeight: '500',
      textAlign: 'center'
    },
    input: {
      backgroundColor: '#F2F5F7',
      borderRadius: 4,
      flex: 1,
      fontSize: 14,
      fontWeight: '500',
      height: 50,
      marginRight: 10,
      paddingHorizontal: 10,
      opacity: 1.0,
    },
    label: {
      color: '#464A53',
      fontWeight: '500',
      marginTop: 15,
      textAlign: 'center'
    },
    horizontalView: {
      flexDirection: 'row',
      justifyContent: 'space-between',
      margin: 20,
      
    }
  });
  