/**
 * Messaging Item
 * @author Ted Bieber
 * @since 10.25.18
 */
import React, {
    Component
  } from 'react';
  import {
    View,
    Text,
    StyleSheet,
    Image,
    TouchableOpacity,
  } from 'react-native';
  
  import Icon from 'react-native-vector-icons/Feather';

  import StorageManager from '../../StorageManager';

  export default class MessagingItem extends Component {
  
    constructor() {
      super();
      this.state = {
        user_id: ""
      }
    }

    componentWillMount() {
      // get our user_id and store it in the state
      StorageManager.getItem('user_id', (response) => {
        this.setState({
          user_id:response
        });
      });
    }

    onPressedThread = () => {
        // this.props.navigation.navigate('Conversation', {
        //   'item':this.props.item, 
        //   'username':this.getDisplayedUsername(), 
        //   'user_id':this.state.user_id
        // });
        this.props.navigation.navigate('Conversation', {
          'user_id1':this.props.item.from_user.user_id,
          'user_id2':this.props.item.to_user.user_id
        });
    }

    /**
     * Since it is difficult to determine the user the message originated from,
     * check both from and to users in the API response and filter out
     * entries containing this user.
     * @return The usernames of the recipients.
     */
    getDisplayedUsername = () => {
      if (this.props.item.from_user.user_id == this.state.user_id) {
        return this.props.item.to_user.username;
      }

      return this.props.item.from_user.username;
    }

    getDisplayedProfilePicture = () => {
      if (this.props.item.from_user.user_id == this.state.user_id) {
        return this.props.item.to_user.profile_picture ? this.props.item.to_user.profile_picture : 'https://i.imgur.com/4yFJHqn.png';
      }
      return this.props.item.from_user.profile_picture ? this.props.item.from_user.profile_picture : 'https://i.imgur.com/4yFJHqn.png';
    }

    /**
     * Render the content of an individual item. The item contains the
     * user's profile picture, username, and most recent message received/sent.
     */
    renderContent = () => {
      return (
        <View 
          alignItems="center" 
          flexDirection="row"
          padding={15}
          >
          
          <Image 
            style={styles.profilePicture}
            source={{uri: this.getDisplayedProfilePicture()}} />

          <View 
            flex={1}>
            <Text style={{ fontSize: 18, fontWeight: '500', marginBottom: 5 }}>{this.getDisplayedUsername()}</Text>
            <Text 
              numberOfLines={2}
              style={{ color: '#BFC4C7', fontSize: 14, fontWeight: '500' }}>{this.props.item.last_message.is_request ? "Trade Request":this.props.item.last_message.message}</Text>
          </View>

          <Icon style={{marginTop: -2}} name="chevron-right" color="#C7C7CC" size={20} />
        </View>
      );
    }

    render() {
      return (
        <View style={styles.container}>
          <TouchableOpacity onPress={this.onPressedThread}>
            { this.renderContent() }
          </TouchableOpacity>

          <View style={{height: 1, backgroundColor: 'grey', opacity: 0.20}} flex={1} />
        </View>
      );
    }
  }
  
  const styles = StyleSheet.create({
    container: {
      backgroundColor: '#FDFDFE',
      flex: 1,
    },
    profilePicture: {
      borderRadius: 25,
      marginRight: 15,
      width: 50, 
      height: 50
    }
  });
  