import React, { Component } from "react";
import {
  Platform,
  View,
  StyleSheet,
  FlatList,
  ActivityIndicator,
  Text
} from "react-native";

import API from "../../API";
import MessagingItem from "./MessagingItem";
import StorageManager from "../../StorageManager";

/**
 * List view containing all of the threads for a user's messages/conversations
 * @author Stephen Andrews
 * @since 10.4.2018
 */
export default class MessagingListView extends Component {
  constructor() {
    super();

    this.state = {
      isLoading: true,
      messageThreads: []
    };
  }
  
  loadData = () => {
    let cb = response => {
      return response.json().then(data => {
        this.setState({
          isLoading: false,
          messageThreads: data
        });
      }).catch((error) => {
        console.log(error);
      });
    };
    
    StorageManager.getItem('user_id', (response) => {
      API.getMessageThreads(response, cb); 
      return;
    });
  }

  componentDidMount() {
    this.loadData();
  }

  componentWillUpdate() {
    // this.state.isLoading = true; // was causing bugs because it didn't get set back
    let cb = response => {
      return response.json().then(data => {
        if (this.state.messageThreads.length != data.length) {
          this.setState({
            isLoading: false,
            messageThreads: data
          });
        }
      }).catch((error) => {
        console.log(error);
      });
    };

    StorageManager.getItem('user_id', (response) => {
      API.getMessageThreads(response, cb); 
      return;
    }, () => {
      console.log("Failed to load user_id");
    });
  }

  refresh = () => {
    let cb = response => {
      return response.json().then(data => {
        if (this.state.messageThreads.length != data.length) {
          this.setState({
            isLoading: false,
            messageThreads: data
          });
        }
      }).catch((error) => {
        console.log(error);
      });
    };

    StorageManager.getItem('user_id', (response) => {
      API.getMessageThreads(response, cb); 
      return;
    }, () => {
      console.log("Failed to load user_id");
    });
  }

  render() {
    if(this.state.messageThreads.length == 0) {
      return (
        <View style={styles.container}>
        <Text style={styles.textstyle}>Pull down to refresh</Text>
        <Text style={styles.textstyle}>You can start a message by intiating a transaction with another user.</Text>
          <FlatList
            data={this.state.messageThreads}
            keyExtractor={(item) => item.id+""}
            renderItem={({item}) => (<MessagingItem {...this.props} item={item} />)}
            refreshing={this.state.isLoading}
            onRefresh={this.refresh}
          />
        </View>
      );
    }
    this.state.messageThreads = this.state.messageThreads.sort(function(a, b){
      if(a && b){
        return (new Date(b.updated)) - (new Date(a.updated));
      }else{
        return 0;
      }
    });

    return (
      <View style={styles.container}>
        <FlatList
          data={this.state.messageThreads}
          keyExtractor={(item) => item.id+""}
          renderItem={({item}) => (<MessagingItem {...this.props} item={item} />)}
          refreshing={this.state.isLoading}
          onRefresh={this.refresh}
        />
      </View>
    );
  }
}

const styles = StyleSheet.create({
  container: {
    flex: 1
  },
  heading: {
    color: "#FFFFFF",
    fontSize: 42,
    fontFamily: Platform.OS === "ios" ? "Helvetica" : "Roboto",
    fontWeight: "500",
    marginBottom: 15,
    marginLeft: 15
  },
  textstyle: {
    color: "#AAAAAA",
    fontSize: 16,
    fontFamily: Platform.OS === "ios" ? "Helvetica" : "Roboto",
    textAlign: 'center',
    marginTop: 50,
  }
});
