import React, {
  Component
} from 'react';

import {
  FlatList,
  StyleSheet,
  View,
} from 'react-native';

import NavigableHeader from '../../components/NavigableHeader';

import API from '../../API';
import StorageManager from '../../StorageManager';
import ActiveListingItem from './ActiveListingItem';

/**
 * Screen for viewing the user's active listings.
 * @author Stephen Andrews
 */
export default class ActiveListings extends Component {

  constructor() {
      super();

      this.state = {
          isLoading: true,
          total: 0,
          items: [],
          user_id: -1
      };
  }

  componentDidMount = () => {
      this.getActiveListings();

      StorageManager.getItem('user_id', (response) => {
        this.setState({user_id: response});
      });
  }

  getActiveListings = () => {
    let cb = (response) => {
      response.json().then((data)=> {
          this.setState({
              items: data,
              isLoading: false
          });
        }).catch((error)=>{
          console.log(error);
        });
      }
      
      StorageManager.getItem('username', (response) => {
          API.getActiveListings(response, cb);
      });
  }

  render() {
      return (
          <View style={styles.container}>
              <NavigableHeader title="Active listings" {...this.props} />

              <View style={styles.content}>
                <FlatList
                  data={this.state.items}
                  keyExtractor={(item) => "" + item.listing_id}
                  renderItem={({item}) => <ActiveListingItem book={item.book} listing={item} user_id={this.state.user_id} {...this.props} />}
                  onEndReachedThreshold={0.25}
                  // onEndReached={this.loadNextPage}
                  onRefresh={this.getActiveListings()}
                  refreshing={this.state.isLoading} />
              </View>
          </View>
      );
  }
}

const styles = StyleSheet.create({
  container: {
    flex: 1,
    backgroundColor: '#FDFDFE',
  },
  content: {
      flex: 1,
      paddingHorizontal: 20
  },

});
