import React, { Component } from 'react';

import {
  Modal,
  Platform,
  View,
  StyleSheet,
  Text,
  TouchableOpacity,
  TextInput,
  Alert
} from 'react-native';

import Icon from 'react-native-vector-icons/Feather';
import { KeyboardAwareScrollView } from 'react-native-keyboard-aware-scroll-view';


import API from "../../API";

/**
 * Contains layout for the bug report modal used in the {@link Profile} screen.
 * @author Stephen Andrews
 */
export default class BugReportModal extends Component {

  constructor() {
    super();

    this.state = {
      report: ""
    }
  }

  /**
   * Renders the header section containing the title and close button.
   */
  renderHeader = () => {
    return (
      <View style={styles.header}>
        <Text style={styles.heading}>Bug Report</Text>

        {/* This needs to be after the text element due to absolute positioning.
            Otherwise, you won't be able to click the button. */}
        <TouchableOpacity 
          onPress={this.props.onPress}
          style={styles.dismissButton}>

          <Icon name="x" color="#FFF" size={30} />
        </TouchableOpacity>
      </View>
    );
  }

  /**
   * Begins the start of a new section with the specified name.
   */
  renderSectionHeader = (name) => {
    return (
      <View flexDirection="row" alignItems="center" marginTop={25}>
        <Text style={styles.sectionHeading}>{name}</Text>
        <View style={{
          backgroundColor: '#FFF',
          marginLeft: 20,
          flex: 1,
          height: 1,
          opacity: .30
        }} />
      </View>
    );
  }

  submitBug = () => {
    if (this.state.report.length == 0) {
      Alert.alert("Please fill our the body of the bug report!");
      return;
    }

    API.submitBugReport(this.props.state.username, this.state.report, (response) => {
      if (response.status == 200) {
        Alert.alert("Thank you for submitting a bug. We will address it as soon as we can!");
      }
    });
  }

  render() {
    return (
      <Modal
        animationType="slide"
        visible={this.props.visible}>

        <View style={styles.container}>
        <KeyboardAwareScrollView enableOnAndroid={true}>

          { this.renderHeader() }
            <View style={styles.contentContainer}>            
              <TextInput
                multiline
                height={250}
                maxLength={1000}
                autoCorrect={true}
                placeholder="Please describe how the bug happened and when in as much detail as possible..."
                returnKeyType="next"
                onChangeText={(text) => this.state.report = text}
                style={styles.input}
              />
            </View>
          </KeyboardAwareScrollView>
          <TouchableOpacity 
            onPress={() => this.submitBug()}
            style={styles.confirmButton}>
            <Text style={styles.confirmButtonText}>Submit</Text>
          </TouchableOpacity>
        </View>
      </Modal>
    );
  }
}

const styles = StyleSheet.create({
  input: {
    borderRadius: 5,
    marginTop: 5,
    paddingLeft: 10,
    backgroundColor: '#FFF',
  },
  container: {
    flex: 1,
    backgroundColor: '#FFBC42'
  },
  contentContainer: {
    flex: 1,
    margin: 15,
  },
  confirmButton: {
    backgroundColor: '#FFF',
    height: 75,
    padding: 25
  },
  confirmButtonText: {
    color: '#FFBC42',
    fontSize: 14,
    fontWeight: '700',
    textAlign: 'center'
  },
  dismissButton: {
    position: 'absolute',
    left: 20
  },
  header: {
    height: 100,
    justifyContent: 'flex-end',
  },
  heading: {
    color: '#FFF',
    fontSize: 24,
    fontFamily: Platform.OS === 'ios' ? 'Helvetica' : 'Roboto',
    fontWeight: 'bold',
    textAlign: 'center'
  },
  sectionHeading: {
    color: '#FFFFFF',
    fontSize: 14,
    fontWeight: '700',
    opacity: .70
  }
});
