import React, {
    Component
  } from 'react';
  
  import {
    Platform,
    StyleSheet,
    View,
    Text,
  } from 'react-native';
  
  import NavigableHeader from '../../components/NavigableHeader';
  import TransactionListView from './TransactionListView';
  
  import API from '../../API';
  import StorageManager from '../../StorageManager';

  /**
   * Defines the Transaction History Screen.
   * @author Stephen Andrews, John Bieber, Ted Bieber
   */
  export default class TransactionHistory extends Component {
  
    constructor() {
        super();
        this.state = {
            isLoading: true,
            total: 0,
            items: []
        };
    }

    componentDidMount = () => {
        let cb = (response) => {
            response.json().then((data)=> {
                this.setState({
                    total:data.total,
                    items:data.items,
                    isLoading:false
                });
              }).catch((error)=>{
                console.log(error);
              });
        }
        
        StorageManager.getItem('user_id', (response) => {
            API.getTransactionHistory(response, cb);
        });

    }

    onListRefreshed = () => {
        let cb = (response) => {
            response.json().then((data)=> {
                this.setState({
                    total:data.total,
                    items:data.items,
                    isLoading:false
                });
              }).catch((error)=>{
                console.log(error);
              });
        }
        
        StorageManager.getItem('user_id', (response) => {
            API.getTransactionHistory(response, cb);
        });
    }


    render() {
        return (
            <View style={styles.container}>
                <NavigableHeader title="Transactions" {...this.props} />

                <View style={styles.content}>
                    <Text style={styles.total}>{"$" + this.state.total}</Text>
                    <Text style={styles.p}>{"Total profits"}</Text>

                    {/* Spacing between total and list view */}
                    <View height={25}></View>

                    <TransactionListView refreshing={this.state.isLoading} onRefresh={this.onListRefreshed} items={this.state.items} {...this.props} />
                </View>
            </View>
        );
    }
  }
  
  const styles = StyleSheet.create({
    container: {
      flex: 1,
      backgroundColor: '#FDFDFE',
    },
    content: {
        flex: 1,
        paddingHorizontal: 20
    },
    total: {
        fontFamily: Platform.OS === 'ios' ? 'Helvetica' : 'Roboto',
        fontSize: 32,
        fontWeight: '500'
    },
    profitView: {
        flex: 1,
        flexDirection: 'row'
    },
    profitsTagText: {
        fontSize: 24,
        fontFamily: Platform.OS === 'ios' ? 'Helvetica' : 'Roboto',
        textAlign: 'left',
        flex: 1
    },
    profitsValueText: {
        fontSize: 24,
        fontFamily: Platform.OS === 'ios' ? 'Helvetica' : 'Roboto',
        textAlign: 'right',
        color: 'green',
        flex: 1
    },
    

  });
  